# Generated by Django 2.2.6 on 2020-04-12 20:49

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('discord_integration', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='discordintegration',
            name='avatar_url',
            field=models.URLField(blank=True, help_text='Override the bot avatar set in the Discord settings.', verbose_name='discord bot avatar'),
        ),
        migrations.AlterField(
            model_name='discordintegration',
            name='webhook_url',
            field=models.URLField(help_text='The Discord webhook url found in the Discord settings.', verbose_name='discord webhook url'),
        ),
    ]
